#include "program_version.h"
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <hardware/btn-hardware.h>
#include <terminal/btn-terminal.h>
#include <terminal/btn-cmds.h>
#include <terminal/nut-cmds.h>
#include <led/btn-led.h>
#include <wsnlab/wsnlab.h>
#include <sys/timer.h>
#include <terminal/eeprom_cmds.h>

#define PROJECT_NAME "template" // TODO: change this to your project name
#define UART_SPEED   57600

/**
 * Initializes the BTnode.
 */
static void btnode_init(void) 
{    
    /* initialize the btnode hardware */
    btn_hardware_init();
    btn_led_init(0);

    char prompt[TERMINAL_MAX_PROMPT_LENGTH];
    u_short mac_address = get_MAC_address_from_EEPROM();

    sprintf( prompt, "[%s@%02X:%02X]$", PROJECT_NAME, mac_address >> 8, 
    	mac_address & 0xFF );
    
    term_init(UART_SPEED, prompt); 
}

/**
 * Registers all supported commands.
 */
static void register_cmds(void)
{
	nut_cmds_register_cmds();
    btn_cmds_register_cmds();
    wsnlab_cmds_register_cmds();
}

int main(void)
{
	btnode_init();
    
    DEBUGB("\n# ----------------------------------------");
    DEBUGB("\n# " PROJECT_NAME " version " PROGRAM_VERSION "\n");
    DEBUGB("# ----------------------------------------\n");
    NutSleep(200);
 
    // register cmds
	register_cmds();
	
    // start terminal
    btn_terminal_run(BTN_TERMINAL_NOFORK, 1024);
    
    // we should never reach this point
    return 1;
}
